/*
 * Copyright (C) 2008 Luke Kenneth Casson Leighton <lkcl@lkcl.net>
 * Copyright (C) 2008 Alp Toker <alp@atoker.com>
 * Copyright (C) 2008 Apple Inc.
 */

#include "config.h"

#include <wtf/GetPtr.h>
#include "CSSRule.h"
#include "CSSValue.h"
#include "CanvasPixelArray.h"
#include "DOMWindow.h"
#include "Element.h"
#include "Entity.h"
#include "Event.h"
#include "GDOMBinding.h"
#include "GDOMObject.h"
#include "HTMLCollection.h"
#include "Node.h"
#include "StyleSheet.h"
#include "Text.h"
#include "gdom/GStringConvert.h"
#include "gdom/GdomEntity.h"
#include "gdom/GdomNode.h"
#include "gdom/PrivateGdomDOMObject.h"
#include "gdom/PrivateGdomEntity.h"
#include "gdom/PrivateGdomNode.h"
#include "gdom/PrivateIntGdomEntity.h"

namespace WebCore {
    gpointer toGDOM(Node* node);
    gpointer toGDOM(CSSValue* node);
    gpointer toGDOM(CSSRule* node);
    gpointer toGDOM(Element* node);
    gpointer toGDOM(Document* node);
    gpointer toGDOM(HTMLCollection* node);
    //gpointer toGDOM(SVGPathSeg* node);
    gpointer toGDOM(StyleSheet* node);
    gpointer toGDOM(EventTargetNode* node);
    gpointer toGDOM(EventTarget* node);
    gpointer toGDOM(Event* node);
    gpointer toGDOM(CanvasPixelArray* node);
    gpointer toGDOM(DOMWindow* node);
    gpointer toGDOM(Text* node);
} // namespace WebCore

namespace WebCore {
} /* namespace WebCore */
extern "C" {

GDOMEntity::GDOMEntity(PassRefPtr<WebCore::Entity> impl)
    : GDOMNode(impl)
{
}

} /* extern "C" */


#include "config.h"
#include "glib-object.h"
#include <webkit/webkitdefines.h>
#include <webkit/webkitprivate.h> 
#include "DOMWindow.h" /* yukk: TODO - make this optional */
#include "Node.h" /* yukk: TODO - make this optional */
#include "NamedNodeMap.h" /* yukk: TODO - make this optional */
#include "CanvasPattern.h" /* yukk: TODO - make this optional */
#include "CanvasGradient.h" /* yukk: TODO - make this optional */
#include "CanvasStyle.h" /* yukk: TODO - make this optional */
#include "CanvasRenderingContext2D.h" /* yukk: TODO - make this optional */
#include <gdom/PrivateGdomDOMObject.h> /* yukk: TODO - make this optional */
#include <gdom/GdomEventTargetNode.h> /* yukk: TODO - make this optional */
#include <gdom/PrivateGdomEventTargetNode.h> /* yukk: TODO - make this optional on EventTarget*/
#include "Entity.h"
#include <gdom/GdomEntity.h>
#include <gdom/PrivateGdomEntity.h>
#include <gdom/PrivateIntGdomEntity.h>
#include <gdom/GdomEntityprops.h>

#include "gdom/GStringConvert.h"

#include "CanvasPixelArray.h"
#include "Event.h"
#include "Text.h"
#include "CSSValue.h"
#include "CSSRule.h"
#include "HTMLCollection.h"
#include "StyleSheet.h"
#include "Document.h"
#include "webkitmarshal.h"
#include <gdom/GdomEvent.h>



namespace WebCore {
    gpointer toGDOM(Node* node);
    gpointer toGDOM(CSSValue* node);
    gpointer toGDOM(CSSRule* node);
    gpointer toGDOM(Element* node);
    gpointer toGDOM(Document* node);
    gpointer toGDOM(HTMLCollection* node);
    //gpointer toGDOM(SVGPathSeg* node);
    gpointer toGDOM(StyleSheet* node);
    gpointer toGDOM(EventTargetNode* node);
    gpointer toGDOM(EventTarget* node);
    gpointer toGDOM(Event* node);
    gpointer toGDOM(CanvasPixelArray* node);
    gpointer toGDOM(DOMWindow* node);
    gpointer toGDOM(Text* node);
} // namespace WebCore



G_BEGIN_DECLS

G_DEFINE_TYPE(GdomEntity, gdom_entity, GDOM_TYPE_NODE);

/*
struct _GdomEntityPrivate {
    class WebCore::Entity *item;
};

#define GDOM_ENTITY_GET_PRIVATE(obj) (G_TYPE_INSTANCE_GET_PRIVATE((obj), GDOM_TYPE_ENTITY, GdomEntityPrivate))
*/
G_END_DECLS
WebCore::Entity *
gdom_entity_get_private(GdomEntity *request)
{
    GDOMEntity *res;
    res = static_cast<GDOMEntity*>(gdom_dom_object_get_private(GDOM_DOM_OBJECT(request)));
    return static_cast<WebCore::Entity*>(res->impl());
}

G_BEGIN_DECLS

enum {
    BROWSER_EVENT,
    LAST_SIGNAL
};

static guint event_signals[LAST_SIGNAL] = { 0, };

enum {
    PROP_0,
    PROP_PUBLIC_ID,
    PROP_SYSTEM_ID,
    PROP_NOTATION_NAME,
};


static void gdom_entity_finalize(GObject* object)
{
    /*GdomEntity* request = GDOM_ENTITY(object);*/
    /*GdomEntityPrivate* priv = request->priv;*/

    /*GObjectClass *parent_class = g_type_class_peek (g_type_peek_parent (GDOM_TYPE_NODE));*/

    /* Free any memory or close any files */

    /*parent_class-> finalize (object);*/

    G_OBJECT_CLASS(gdom_entity_parent_class)->finalize(object);
}

static void gdom_entity__set_property_fn(GObject * object, guint prop_id,
                     const GValue * value,
                     GParamSpec * pspec)
{
    GdomEntity *self = GDOM_ENTITY(object);
    WebCore::Entity * gself = (gdom_entity_get_private(self));
    switch (prop_id) {
    default:
        G_OBJECT_WARN_INVALID_PROPERTY_ID(object, prop_id, pspec);
        break;
    }
}


static void gdom_entity__get_property_fn(GObject * object, guint prop_id,
                     GValue * value,
                     GParamSpec * pspec)
{
    GdomEntity *self = GDOM_ENTITY(object);
    WebCore::Entity * gself = (gdom_entity_get_private(self));
    switch (prop_id) {
    case PROP_PUBLIC_ID:
    {
         g_value_set_string (value, _G_GET_UTF8(gself->publicId()));
         break;
    }
    case PROP_SYSTEM_ID:
    {
         g_value_set_string (value, _G_GET_UTF8(gself->systemId()));
         break;
    }
    case PROP_NOTATION_NAME:
    {
         g_value_set_string (value, _G_GET_UTF8(gself->notationName()));
         break;
    }
    default:
        G_OBJECT_WARN_INVALID_PROPERTY_ID(object, prop_id, pspec);
        break;
    }
}


static void gdom_entity_class_init(GdomEntityClass* requestClass)
{
    GObjectClass *g_klass = G_OBJECT_CLASS (requestClass);
    g_klass->finalize = gdom_entity_finalize;
    g_klass->set_property = gdom_entity__set_property_fn;
    g_klass->get_property = gdom_entity__get_property_fn;

    g_object_class_install_property (g_klass, PROP_PUBLIC_ID,
            g_param_spec_string ("public_id", /* name */
                "entity_public_id", /* short description */
                "read-only  gchar * Entity.public_id", /* longer - could do with some extra doc stuff here */
                 "", /* default */
                 (GParamFlags)G_PARAM_READABLE));

     g_object_class_install_property (g_klass, PROP_SYSTEM_ID,
            g_param_spec_string ("system_id", /* name */
                "entity_system_id", /* short description */
                "read-only  gchar * Entity.system_id", /* longer - could do with some extra doc stuff here */
                 "", /* default */
                 (GParamFlags)G_PARAM_READABLE));

     g_object_class_install_property (g_klass, PROP_NOTATION_NAME,
            g_param_spec_string ("notation_name", /* name */
                "entity_notation_name", /* short description */
                "read-only  gchar * Entity.notation_name", /* longer - could do with some extra doc stuff here */
                 "", /* default */
                 (GParamFlags)G_PARAM_READABLE));





    /*g_type_class_remove_private(requestClass, sizeof(GdomEntityPrivate));*/
}

static void gdom_entity_init(GdomEntity* request)
{
    /*GdomEntityPrivate* priv = GDOM_ENTITY_GET_PRIVATE(request);
    request->priv = priv;*/
}

} /* extern "C" */

